.. episuite documentation master file, created by
   sphinx-quickstart on Fri Mar 12 13:52:24 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. image:: _static/banner.png
   :width: 600
   :align: center
   :alt: Banner

Episuite
=============================
|Development Status| |Run Tests| |PyPi Shield| |Coverage Status|

Welcome to **Episuite**. Episuite is a suite of tools for epidemiology 
in Python.

.. note:: Episuite is currently under development, and accepting contributions. The
          API might change in early development stages.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   installation
   changelog
   gettingstarted
   api
   bibliography
   license
   
Indices and tables
------------------------------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

----------------------------------------

.. |Development Status| image:: https://img.shields.io/badge/Development%20Status-2%20--%20Alpha-yellow
.. |Run Tests| image:: https://github.com/perone/episuite/workflows/CI/badge.svg
   :target: https://github.com/perone/episuite/actions?query=workflow%3A%22CI%22+branch%3Amain
.. |PyPi Shield| image:: https://img.shields.io/pypi/v/episuite.svg
   :target: https://pypi.python.org/pypi/episuite
.. |Coverage Status| image:: https://codecov.io/gh/perone/episuite/branch/main/graph/badge.svg?token=XE5J0UX1U4
   :target: https://codecov.io/gh/perone/episuite
